unit Stringz;

interface

uses
	SysUtils;

Function BeginsWith ( sFull, sBegin : String ) : Boolean;
Function PosR ( subStr, Str : String ) : Integer;

Function RemoveFromLeft ( s : String; Count : Integer ) : String;
Function RemoveFromRight ( s : String; Count : Integer ) : String;
Function KeepFromRight ( s : String; Count : Integer ) : String;

Function RemoveString ( Str, subStr : String ) : String;
function RemoveChars ( Str : String; cChr : Char ) : String;
procedure Split ( Orig : String; Var beg : String; Var rest : String; Mark : Char );
procedure SplitAtMark ( Var s1 : String; Var s2 : String; Mark : Char );
Function Replace ( sOrig, sFind, sRepl : String ) : String;

Function Comma ( i : Integer ) : String;
Function Zero ( i, Digits : Integer ) : String;
Function StringToAscii ( s : String ) : String;
Function IsNumbers ( s : String ) : Boolean;
Function SafeVal ( s : String ) : Integer;

implementation

{*********************************************************************}
Function BeginsWith ( sFull, sBegin : String ) : Boolean;
begin
	if Copy ( sFull, 1, Length ( sBegin ) ) = sBegin then
	begin
		BeginsWith := True;
	end
	else
	begin
		BeginsWith := False;
	end;
end;

{*********************************************************************}
Function PosR ( subStr, Str : String ) : Integer;
var
	i : Integer;
	Lsub : Integer;
begin
	Lsub := Length ( subStr );
	i := Length ( Str ) - Lsub + 1;
	while ( i > 0 ) and ( subStr <> Copy ( Str, i, Lsub ) ) do begin
		dec ( i );
	end;
	PosR := i;
end;

{*********************************************************************}
Function RemoveFromLeft ( s : String; Count : Integer ) : String;
begin
	if Count > Length ( s ) then
		RemoveFromLeft := ''
	else
		RemoveFromLeft := Copy ( s, Count + 1, Length ( s ) - Count );
end;

{*********************************************************************}
Function RemoveFromRight ( s : String; Count : Integer ) : String;
begin
	if Count > Length ( s ) then
		RemoveFromRight := ''
	else
		RemoveFromRight := Copy ( s, 1, Length ( s ) - Count );
end;

Function KeepFromRight ( s : String; Count : Integer ) : String;
begin
	if Count > Length ( s ) then
		KeepFromRight := s
	else
		KeepFromRight := Copy ( s, Length ( s ) - ( Count - 1 ), Count );
end;

{*********************************************************************}
Function RemoveString ( Str, subStr : String ) : String;
var
	p : Integer;
begin
	p := Pos ( subStr, Str );
	if p > 0 then
	begin
		Str := Copy ( Str, 1, p - 1 ) +
			Copy ( Str, p + Length ( subStr ),
				Length ( Str ) - ( p + Length ( subStr ) - 1 ) )
	end;
	RemoveString := Str;
end;

{*********************************************************************}
function RemoveChars ( Str : String; cChr : Char ) : String;
var
	p : Integer;
	sTemp : String;
begin
	sTemp := '';
	For p := 1 To Length ( Str ) Do
	Begin
		If Copy ( Str, p, 1 ) <> cChr Then
		Begin
			sTemp := sTemp + Copy ( Str, p, 1 );
		End;
	End;
	RemoveChars := sTemp;
end;

{*********************************************************************}
procedure Split ( Orig : String; Var beg : String; Var rest : String; Mark : Char );
var
	p : Integer;
begin
	p := Pos ( Mark, Orig );
	if p = 0 then
	begin
		{ s1 stays as it is }
		beg := Orig;
		rest := '';
	end
	else
	begin
		beg := Copy ( Orig, 1, p - 1 );
		rest := Copy ( Orig, p + 1, Length ( Orig ) - p );
	end;
end;

{*********************************************************************}
procedure SplitAtMark ( Var s1 : String; Var s2 : String; Mark : Char );
var
	p : Integer;
begin
	p := Pos ( Mark, s1 );
	if p = 0 then
	begin
		{ s1 stays as it is }
		s2 := '';
	end
	else
	begin
		s2 := Copy ( s1, p + 1, Length ( s1 ) - p );
		s1 := Copy ( s1, 1, p - 1 );
	end;
end;

{*********************************************************************}
Function Replace ( sOrig, sFind, sRepl : String ) : String;
Var
	i : Integer;
Begin
	i := Pos ( sFind, sOrig );
	//
	While i > 0 Do
	Begin
		sOrig := Copy ( sOrig, 1, i - 1 ) + sRepl +
			Copy ( sOrig, i + Length ( sFind ), Length ( sOrig ) );
		//
		i := Pos ( sFind, sOrig );
	End;
	//
	Replace := sOrig;
End;

{*********************************************************************}
Function Comma ( i : Integer ) : String;
Var
	s, sSign : String;
	{sDecimals : String;}
	p : Integer;
Begin
	s := IntToStr ( i );
	//
	If s [ 1 ] = '-' Then
	Begin
		sSign := '-';
		s := RemoveFromLeft ( s, 1 );
	End
	Else
		sSign := '';
	//
	{
	p := Pos ( '.', s );
	If p > 0 Then
	Begin
		sDecimals := RemoveFromLeft ( s, p );
		s := Copy ( s, 1, p - 1 );
	End
	Else
		sDecimals := '';
	}
	//
	p := 3;
	While p < Length ( s ) Do
	Begin
		s := Copy ( s, 1, Length ( s ) - p ) + ',' + Copy ( s, Length ( s ) - p + 1, p );
		Inc ( p, 4 );
	End;
	//
	Comma := sSign + s;
End;

{*********************************************************************}
Function Zero ( i, Digits : Integer ) : String;
var
	s : String;
Begin
	s := IntToStr ( i );
	While Length ( s ) < Digits Do
		s := '0' + s;
	Zero := s;
End;

{*********************************************************************}
Function StringToAscii ( s : String ) : String;
const
	AccentedChars = '';
	AsciiChars    = 'aeioooouuuAEOU';
var
	p, i : Integer;
	s2 : String;
begin
	for i := 1 To Length ( s ) Do
	Begin
		p := Pos ( s [ i ], AccentedChars );
		If p > 0 Then
			s2 := s2 + AsciiChars [ p ]
		Else
			s2 := s2 + s [ i ];
	End;
	StringToAscii := s2;
end;

Function IsNumbers ( s : String ) : Boolean;
var
	i : Integer;
	ok : Boolean;
	Radix : Integer;
Begin
	s := Trim ( s );
	//
	Radix := 10; // decimal
	//
	If Length ( s ) > 0 Then
		If s [ 1 ] = '-' Then
			s := RemoveFromLeft ( s, 1 );
	//
	If Length ( s ) > 0 Then
		If s [ 1 ] = '$' Then
		Begin
			s := RemoveFromLeft ( s, 1 );
			Radix := 16; // hex
		End;
	//
	If Length ( s ) > 0 Then
	Begin
		i := 1;
		ok := True;
		//
		While ok And ( i <= Length ( s ) ) Do
		Begin
			If ( Radix = 16 ) Then
			Begin
				If Not ( ( s [ i ] >= '0' ) And ( s [ i ] <= '9' ) )
				And Not ( ( s [ i ] >= 'A' ) And ( s [ i ] <= 'F' ) )
				And Not ( ( s [ i ] >= 'a' ) And ( s [ i ] <= 'f' ) ) Then
				Begin
					Ok := False;
				End;
			End
			Else
			Begin
				If Not ( ( s [ i ] >= '0' ) And ( s [ i ] <= '9' ) ) Then
				Begin
					Ok := False;
				End;
			End;
			Inc ( i );
		End;
		IsNumbers := Ok;
	End
	Else
		IsNumbers := False;
End;

Function SafeVal ( s : String ) : Integer;
var
	sTemp : String;
Begin
	sTemp := Trim ( s );
	While Pos ( ',', sTemp ) > 0 Do
	Begin
		sTemp := RemoveString ( sTemp, ',' );
	End;
	//
	If IsNumbers ( sTemp ) Then
	Begin
		SafeVal := StrToInt ( sTemp );
	End
	Else
	Begin
		SafeVal := 0;
	End;
End;

end.
